HDF5 Writer
===========

.. automodule:: polar2grid.writers.hdf5
    :noindex:

Command Line Arguments
----------------------

.. argparse::
    :module: polar2grid.writers.hdf5
    :func: add_writer_argument_groups
    :prog: polar2grid.sh -r <reader> -w hdf5
    :passparser:
